#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lpeg
version:              1.1.0
visibility:           public
id:                   lpeg-1.1.0-4NTpZIQmy7fCf9wMhHwGuJ
key:                  lpeg-1.1.0-4NTpZIQmy7fCf9wMhHwGuJ
license:              MIT
copyright:
    © 2007-2019 Lua.org, PUC-Rio;
    © 2021-2023 Albert Krewinkel

maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             LPeg – Parsing Expression Grammars For Lua
description:
    This package contains the C sources of LPeg, as well
    as some tiny Haskell helper to load the package.

    <http://www.inf.puc-rio.br/~roberto/lpeg/>

category:             Foreign
abi:                  4cfb093b88cab806a076c8ac931df82a
exposed:              True
exposed-modules:      Lua.LPeg
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lpeg-1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lpeg-1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lpeg-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lpeg
hs-libraries:         HSlpeg-1.1.0-4NTpZIQmy7fCf9wMhHwGuJ
depends:              base-4.18.2.1 lua-2.3.4-L9ieHrsZ26w7a2K8q4TkNc
haddock-interfaces:   /usr/share/doc/haskell-lpeg/html/lpeg.haddock
haddock-html:         /usr/share/doc/haskell-lpeg/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

